package Check;

my $pkg="Check";

use strict;
use My;
use Info;
use Class::Date qw(date);

#======== Funkce kontrolujici zda je vstup ok - kdyz neni vraci undef, kdyz je vraci hodnotu co se ma ulozit do tabulky
#- kontrola zak - pokud ok vrati neformatovane cislo zakazky
sub check_zak {
   my ($pkg_p, $field_val)=@_;
   $field_val=~s/ //g;
   if($field_val!~/^(\d){14}$/) {
      $field_val=undef;
   }
   return $field_val;
}
#- kontrola mat
sub check_mat {
   my ($pkg_p, $field_val)=@_;
   if($field_val!~/^(\d){6}$/) {
      $field_val=undef;
   }
   return $field_val;
}
#- kontrola nar - pokud ok vrati neformatovane cislo naradi
sub check_nar {
   my ($pkg_p, $field_val)=@_;
   $field_val=~s/ //g;
   if($field_val!~/^([\dK][\dA-Z]\d\d{4}\d)$/) {
      $field_val=undef;
   }
   return $field_val;
}
#- kontrola oper
sub check_oper {
   my ($pkg_p, $field_val)=@_;
   if($field_val!~/^(\d){3}$/) {
      $field_val=undef;
   }
   return $field_val;
}
#- kontrola kmint
sub check_kmint {
   my ($pkg_p, $field_val)=@_;
   if($field_val!~/^(\d){3}$/) {
      $field_val=undef;
   }
   return $field_val;
}
#- kontrola str
sub check_str {
   my ($pkg_p, $field_val)=@_;
   if($field_val!~/^[\dA-Z]{4,6}$/) {
      $field_val=undef;
   }
   return $field_val;
}
#- kontrola prac
sub check_prac {
   my ($pkg_p, $field_val)=@_;
   if($field_val!~/^\d{7}$/) {
      $field_val=undef;
   }
   return $field_val;
}
#- kontrola sklad
sub check_sklad {
   my ($pkg_p, $field_val)=@_;
   if($field_val!~/^\d{6}$/) {
      $field_val=undef;
   }
   return $field_val;
}
#- kontrola oc
sub check_oc {
   my ($pkg_p, $field_val)=@_;
   if($field_val!~/^[\da-z]{4}$/ and $field_val!~/^K\d{3}$/) { # kolektivi zacinaji pismenem K
      $field_val=undef;
   }
   return $field_val;
}
#- kontrola znam
sub check_znam {
   my ($pkg_p, $field_val)=@_;
   if($field_val ne "+" and $field_val ne "-") {
      $field_val=undef;
   }
   return $field_val;
}
#- kontrola tt
sub check_tt {
   my ($pkg_p, $field_val)=@_;
   if($field_val!~/^\d\d[12]$/) { # nejsem si jist zda THP pracovnici maji mit na konci 2 (mozna ze tam maj mit 0)
      $field_val=undef;
   }
   return $field_val;
}
#- kontrola dm
sub check_dm {
   my ($pkg_p, $field_val)=@_;
   if($field_val!~/^\d{2}$/) {
      $field_val=undef;
   }
   return $field_val;
}
#- kontrola roku
sub check_rok {
   my ($pkg_p, $field_val)=@_;
   if($field_val!~/^\d{4}$/) {
      $field_val=undef;
   }
   return $field_val;
}
#- kontrola datum - pokud je datum platne tak ho vrati, jinak vrati undef
sub check_datum {
   my ($pkg_p, $field_val)=@_;
   $field_val=My->check_datum($field_val);
   return $field_val;
}
# kontrola platnosti datumu od - musi to byt zacatek soucasne ci budouci dekady
sub check_datum_platod {
   my ($pkg_p, $field_val)=@_;
   if($pkg->check_datum($field_val) and $field_val ge My->date_present) {
      my $dd=substr($field_val,8,2);
      if($dd ne "01" and $dd ne "11" and $dd ne "21") {
         $field_val=undef;
      }
   }
   else {
      $field_val=undef;
   }
   return $field_val;
}
# kontrola platnosti datumu do - musi to byt konec soucasne ci budouci dekady
sub check_datum_platdo {
   my ($pkg_p, $field_val)=@_;
   if($pkg->check_datum($field_val) and $field_val ge My->date_present) {
      my $dd=substr($field_val,8,2);
      my $ddmonth;
      if($field_val eq "9999-12-31") { # bohuzel knihovna na zjistovani poctu dni v mesici pracuje jen do roku 2036 - ja zde roky nad 2036 vlastne neresim a zabyvam se jen specialnim datem "9999-12-31"
         $ddmonth="31";
      }
      else {
         $ddmonth=date($field_val)->days_in_month;
      }
      if($dd ne "10" and $dd ne "20" and $dd ne $ddmonth) {
         $field_val=undef;
      }
   }
   else {
      $field_val=undef;
   }
   return $field_val;
}
# kontrola datumu platnosti u novych akt fci - musi jit o platne datum, ktere nahradim zacatkem dekady a ta dekada musi byt soucasna ci budouci
sub check_datum_aktplatnost {
   my ($pkg_p, $field_val)=@_;
   if($pkg->check_datum($field_val)) {
      $field_val=My->date_adddecade($field_val,0);
      if(My->date_adddecade($field_val,-1) lt My->date_present) {
         $field_val=undef;
      }
   }
   else {
      $field_val=undef;
   }
   return $field_val;
}
#- kontrola platnosti ucetniho obdobi - 2
sub check_ucetobd {
   my ($pkg_p, $field_val)=@_;
   if($field_val=~/^(\d{4})\-(\d{2})$/) {
      my $mes=$2;
      if(!($mes>=1 and $mes<=12)) {
         $field_val=undef;
      }
   }
   else {
      $field_val=undef;
   }
   return $field_val;
}
#- kontrola platnosti ucetniho obdobi - 2
sub check_ucetobd0 {
   my ($pkg_p, $field_val)=@_;
   if($field_val ne "0000-00") {
      $field_val=$pkg->check_ucetobd($field_val);
   }
   return $field_val;
}
#- kontrola pocetobd
sub check_pocetobd {
   my ($pkg_p, $field_val)=@_;
   my $max=24;
   if(My->okruh=~/Vyroba_kapacity/) {
      $max=12;
   }
   $field_val*=1;
   if($field_val<0 or $field_val>$max) {
      $field_val=undef;
   }
   return $field_val;
}
#- kontrola zak - pokud je zatrzeno odzak je kontrola formalni, pokud ne je fce shodna s fci exist_zak
sub check_odzak {
   my ($pkg_p, $field_val,$field,$polozky)=@_;
   $field_val=~s/ //g;
   if($$polozky{odzak}{value}) {
      if($field_val!~/^(\d){0,14}$/) {
         $field_val=undef;
      }
   }
   else {
      $field_val=$pkg->exist_zak($field_val);
   }
   return $field_val;
}
#- kontrola zak - dozak
sub check_dozak {
   my ($pkg_p, $field_val,$field,$polozky)=@_;
   $field_val=~s/ //g;
   if($field_val!~/^(\d){0,14}$/) {
      $field_val=undef;
   }
   return $field_val;
}
#- kontrola zak ve spojeni s prepinacem udajzak
sub check_udajzak {
   my ($pkg_p, $field_val,$field,$polozky)=@_;
   $field_val=~s/ //g;
   if($$polozky{udajzak}{value}==1) {
      if($field_val!~/^(\d){0,14}$/) {
         $field_val=undef;
      }
   }
   else {
      $field_val=$pkg->exist_zak($field_val);
   }
   return $field_val;
}
#- kontrola mat ve spojeni s prepinacem udajmat
sub check_udajmat {
   my ($pkg_p, $field_val,$field,$polozky)=@_;
   if($$polozky{udajmat}{value}==1) {
      if($field_val!~/^(\d){0,6}$/) {
         $field_val=undef;
      }
   }
   else {
      $field_val=$pkg->exist_mat($field_val);
   }
   return $field_val;
}
#- kontrola nar ve spojeni s prepinacem udajnar
sub check_udajnar {
   my ($pkg_p, $field_val,$field,$polozky)=@_;
   if($$polozky{udajnar}{value}==1) {
      if($field_val!~/^(\d){0,6}$/) {
         $field_val=undef;
      }
   }
   else {
      $field_val=$pkg->exist_nar($field_val);
   }
   return $field_val;
}
#- kontrola sklad ve spojeni s prepinacem udajsklad
sub check_udajsklad {
   my ($pkg_p, $field_val,$field,$polozky)=@_;
   if($$polozky{udajsklad}{value}==1) {
      if($field_val!~/^(\d){0,6}$/) {
         $field_val=undef;
      }
   }
   else {
      $field_val=$pkg->exist_sklad($field_val);
   }
   return $field_val;
}
#- kontrola oper - pokud je zatrzeno odoper je kontrola formalni, pokud ne je fce shodna s fci exist_oper
sub check_odoper {
   my ($pkg_p, $field_val,$field,$polozky)=@_;
   if($$polozky{odoper}{value}) {
      $field_val=$pkg->check_oper($field_val);
   }
   else {
      $field_val=$pkg->exist_oper($field_val,"oper",$polozky);
   }
   return $field_val;
}
#- kontrola str ve spojeni s prepinacem udajstr
sub check_udajstr {
   my ($pkg_p, $field_val,$field,$polozky)=@_;
   if($$polozky{udajstr}{value}==1) {
      if($field_val!~/^(\d){0,4}$/) {
         $field_val=undef;
      }
   }
   else {
      $field_val=$pkg->exist_str($field_val);
   }
   return $field_val;
}
#- kontrola oc ve spojeni s prepinacem udajoc
sub check_udajoc {
   my ($pkg_p, $field_val,$field,$polozky)=@_;
   if($$polozky{udajoc}{value}==1) {
      if($field_val!~/^[\da-zK]{0,1}[\da-z]{0,3}$/) {
         $field_val=undef;
      }
   }
   else {
      $field_val=$pkg->exist_oc($field_val);
   }
   return $field_val;
}
#- kontrola okruhu zda obsahuje mozne znaky
sub check_okruh {
   my ($pkg_p, $field_val)=@_;
   ## ZMENA 2003-09-08 - povoleny jeste znak -
   ## ZMENA 2003-09-19 - povoleny jeste znak ~
   ## ZMENA 2003-10-31 - povoleny jeste znak =
   if(!($field_val=~/^\// and $field_val=~/^[\/\#\_\-\~\.\*\@\=0-9a-zA-Z]+$/)) {
      $field_val=undef;
   }
   return $field_val;
}
#- kontrola zda je hodnota neprazdna
sub check_noempty {
   my ($pkg_p, $field_val)=@_;
   if(!length($field_val)) {
      $field_val=undef;
   }
   return $field_val;
}
#- kontrola existence zak - pokud nalezne vrati neformatovane cislo zakazky - 2
sub exist_zak {
   my ($pkg_p, $field_val)=@_;
   $field_val=~s/ //g;
   my $ref=Info->zak($field_val);
   if(!$$ref{_exist}) {
      $field_val=undef;
   }
   return $field_val;
}
#- kontrola existence zak ve spojeni s kmorg dle promene prostredi org - vhodne pro akt. fce
sub exist_zak_kmorg {
   my ($pkg_p, $field_val)=@_;
   $field_val=~s/ //g;
   my $ref=Info->zak($field_val);
   if(!$$ref{_exist}) {
      $field_val=undef;
   }
   elsif($$ref{kmorg} ne get_env("org")) {
      $field_val=undef;
   }
   return $field_val;
}
#- kontrola existence zak ve spojeni s vykrorg dle promene prostredi org - vhodne pro akt. fce
sub exist_zak_vykrorg {
   my ($pkg_p, $field_val)=@_;
   $field_val=~s/ //g;
   my $ref=Info->zak($field_val);
   if(!$$ref{_exist}) {
      $field_val=undef;
   }
   elsif($$ref{vykrorg} ne get_env("org")) {
      $field_val=undef;
   }
   return $field_val;
}
#- kontrola uplnosti a to v organizacnim i holdingovem pohledu
sub exist_zak_upl {
   my ($pkg_p, $field_val)=@_;
   $field_val=$pkg->exist_zak($field_val);
   if(defined($field_val) and (My->date_now lt "2003-05-30" or My->date_now gt "2003-06-02")) {
      my $info_zak=Info->zak($field_val);
      my $info_kmorg=Info->org($$info_zak{kmorg});
      my $info_vnitr_ceny;
      if($$info_kmorg{vcorg} eq "1") {
         my $Eorg=get_env("org");
         set_env("org",$$info_zak{kmorg});
         $info_vnitr_ceny=Info->vnitr_ceny($field_val,"*");
         set_env("org",$Eorg);
      }
      else {
         $info_vnitr_ceny=Info->vnitr_ceny($field_val,"*");
      }
      if($$info_vnitr_ceny{znupl} ne "0") {
         $field_val=undef;
      }
   }
   return $field_val;
}
#- kontrola mat
sub check_odmat {
   my ($pkg_p, $field_val,$field,$polozky)=@_;
   if($$polozky{odmat}{value}) {
      if($field_val!~/^(\d){6}$/) {
         $field_val=undef;
      }
   }
   else {
      $field_val=$pkg->exist_mat($field_val);
   }
   return $field_val;
}
#- kontrola existence mat - 2
sub exist_mat {
   my ($pkg_p, $field_val)=@_;
   my $dbh=My->dbh;
   my $sth=$dbh->prepare(q{
      select
         Material.mat
      from
         Material.Material
      where
         Material.mat=? and
         Material.platod<=? and
         Material.platdo>=?
   });
   $sth->execute($field_val,get_env("datum"),get_env("datum"));
   if(!$sth->rows) {
      $field_val=undef;
   }
   $sth->finish;
   return $field_val;
}
#- kontrola existence nar
sub exist_nar {
   my ($pkg_p, $field_val)=@_;
   $field_val=~s/ //g;
   my $dbh=My->dbh;
   my $sth=$dbh->prepare(q{
      select
         Naradi.nar
      from
         Naradi.Naradi
      where
         Naradi.nar=? and
         Naradi.platod<=? and
         Naradi.platdo>=?
   });
   $sth->execute($field_val,get_env("datum"),get_env("datum"));
   if(!$sth->rows) {
      $field_val=undef;
   }
   $sth->finish;
   return $field_val;
}
#- kontrola existence skladu - 2
sub exist_sklad {
   my ($pkg_p, $field_val)=@_;
   my $ref=Info->sklad($field_val);
   if(!$$ref{_exist}) {
      $field_val=undef;
   }
   return $field_val;
}
#- kontrola existence skladu - 3 - v uvahu beru i org
sub exist_sklad_org {
   my ($pkg_p, $field_val)=@_;
   my $ref=Info->sklad($field_val);
   if(!$$ref{_exist}) {
      $field_val=undef;
   }
   else {
      my $info_str=Info->str($$ref{supstr});
      if($$info_str{org} ne get_env("org")) {
         $field_val=undef;
      }
   }
   return $field_val;
}
#- kontrola operace, zda existuje ve vyrobnim postupu
sub exist_oper {
   my ($pkg_p, $field_val,$field,$polozky)=@_;
   my $operl=Info->vyrobni_postup_oper($$polozky{zak}{value});
   if(!$$operl{$field_val}) {
      $field_val=undef;
   }
   return $field_val;
}
#- kontroluje zda existuje u dane zak kmint
sub exist_kmint {
   my ($pkg_p, $field_val,$field,$polozky)=@_;
   my $normativ=Info->normativy($$polozky{zak}{value},$field_val);
   if(!length($$normativ{kmint})) {
      $field_val=undef;
   }
   return $field_val;
}
#- kontrola ch
sub exist_ch {
   my ($pkg_p, $field_val)=@_;
   my $dbh=My->dbh;
   my $sth=$dbh->prepare(q{
      select
         Charakteristiky.ch
      from
         Zakazky.Charakteristiky
      where
         Charakteristiky.ch=?
   });
   $sth->execute($field_val);
   if(!$sth->rows) {
      $field_val=undef;
   }
   $sth->finish;
   return $field_val;
}
#- kontrola mj
sub exist_mj {
   my ($pkg_p, $field_val)=@_;
   my $dbh=My->dbh;
   my $sth=$dbh->prepare(q{
      select
         Mj.mj
      from
         Zakazky.Mj
      where
         Mj.mj=?
   });
   $sth->execute($field_val);
   if(!$sth->rows) {
      $field_val=undef;
   }
   $sth->finish;
   return $field_val;
}
#- kontrola org - 2
sub exist_org {
   my ($pkg_p, $field_val)=@_;
   my $dbh=My->dbh;
   my $sth=$dbh->prepare(q{
      select
         Org.org
      from
         Spolecnost.Org
      where
         Org.org=?
   });
   $sth->execute($field_val);
   if(!$sth->rows) {
      $field_val=undef;
   }
   $sth->finish;
   return $field_val;
}
#- kontrola na ico v adresari
sub exist_ico {
   my ($pkg_p, $field_val)=@_;
   my $dbh=My->dbh;
   my $sth=$dbh->prepare(q{
      select
         Adresar.ico
      from
         Spolecnost.Adresar
      where
         Adresar.ico=?
   });
   $sth->execute($field_val);
   if(!$sth->rows) {
      $field_val=undef;
   }
   $sth->finish;
   return $field_val;
}
#- kontrola na ico v adresari
sub exist_partner {
   my ($pkg_p, $field_val)=@_;
   my $ref=Info->partner($field_val);
   if(!$$ref{_exist}) {
      $field_val=undef;
   }
   return $field_val;
}
#- kontrola str - 2
sub exist_str {
   my ($pkg_p, $field_val,$field,$polozky)=@_;
   my $dbh=My->dbh;
   my $sth=$dbh->prepare(q{
      select
         Str.str
      from
         Spolecnost.Str
      where
         Str.str=? and
         Str.platod<=? and
         Str.platdo>=?
   });
   $sth->execute($field_val,get_env("datum"),get_env("datum"));
   if(!$sth->rows) {
      $field_val=undef;
   }
   $sth->finish;
   return $field_val;
}
#- kontrola str - 3 - v uvahu beru i org
sub exist_str_org {
   my ($pkg_p, $field_val,$field,$polozky)=@_;
   my $dbh=My->dbh;
   my $sth=$dbh->prepare(q{
      select
         Str.str
      from
         Spolecnost.Str
      where
         Str.str=? and
         Str.platod<=? and
         Str.platdo>=? and
         Str.org=?
   });
   $sth->execute($field_val,get_env("datum"),get_env("datum"),get_env("org"));
   if(!$sth->rows) {
      $field_val=undef;
   }
   $sth->finish;
   return $field_val;
}
#- kontrola oc - musi byt ve stavu
sub exist_oc_stavzam {
   my ($pkg_p, $field_val,$field,$polozky)=@_;
   my $dbh=My->dbh;
   my $sth=$dbh->prepare(q{
      select
         Zamestnanci_zamestnani.oc
      from
         Zamestnanci.Zamestnanci_zamestnani
      where
         Zamestnanci_zamestnani.oc=? and
         Zamestnanci_zamestnani.stavzam=? and
         Zamestnanci_zamestnani.platod<=? and
         Zamestnanci_zamestnani.platdo>=?
   });
   $sth->execute($field_val,"A",get_env("datum"),get_env("datum"));
   if(!$sth->rows) {
      $field_val=undef;
   }
   $sth->finish;
   return $field_val;
}
#- kontrola oc - nemusi byt ve stavu, staci, kdyz existuje
sub exist_oc {
   my ($pkg_p, $field_val,$field,$polozky)=@_;
   my $dbh=My->dbh;
   my $sth=$dbh->prepare(q{
      select
         Zamestnanci.oc
      from
         Zamestnanci.Zamestnanci
      where
         Zamestnanci.oc=? and
         Zamestnanci.platod<=? and
         Zamestnanci.platdo>=?
   });
   $sth->execute($field_val,get_env("datum"),get_env("datum"));
   if(!$sth->rows) {
      $field_val=undef;
   }
   $sth->finish;
   return $field_val;
}
#- kontrola prac - 2
sub exist_prac {
   my ($pkg_p, $field_val,$field,$polozky,$str)=@_;
   if(!defined($str)) {
      $str=$$polozky{str}{value};
   }
   my $dbh=My->dbh;
   if($str ne "") {
      my $sth=$dbh->prepare(q{
         select
            Pracoviste.prac
         from
            Vyroba_priprava.Pracoviste
         where
            Pracoviste.str=? and
            Pracoviste.prac=? and
            Pracoviste.platod<=? and
            Pracoviste.platdo>=?
      });
      $sth->execute($str,$field_val,get_env("datum"),get_env("datum"));
      if(!$sth->rows) {
         $field_val=undef;
      }
      $sth->finish;
   }
   else {
      my $sth=$dbh->prepare(q{
         select
            Pracoviste.prac
         from
            Vyroba_priprava.Pracoviste
         where
            Pracoviste.prac=? and
            Pracoviste.platod<=? and
            Pracoviste.platdo>=?
      });
      $sth->execute($field_val,get_env("datum"),get_env("datum"));
      if(!$sth->rows) {
         $field_val=undef;
      }
      $sth->finish;
   }
   return $field_val;
}
#- kontrola inidikace
sub exist_ind_kusovnik {
   my ($pkg_p,$field_val,$field,$polozky)=@_;
   my $dbh=My->dbh;
   my $sth=$dbh->prepare(q{
      select
         Ind_Kusovnik.ind
      from
         Zakazky.Ind_Kusovnik
      where
         Ind_Kusovnik.ind=?
   });
   $sth->execute($field_val);
   if(!$sth->rows) {
      $field_val=undef;
   }
   $sth->finish;
   return $field_val;
}
#- kontrola inidikace
sub exist_ind_vykon_norma {
   my ($pkg_p,$field_val,$field,$polozky)=@_;
   my $dbh=My->dbh;
   my $sth=$dbh->prepare(q{
      select
         Ind_Vykon_norma.ind
      from
         Vyroba_priprava.Ind_Vykon_norma
      where
         Ind_Vykon_norma.ind=?
   });
   $sth->execute($field_val);
   if(!$sth->rows) {
      $field_val=undef;
   }
   $sth->finish;
   return $field_val;
}
#- kontrola inidikace
sub exist_ind_naradi_norma {
   my ($pkg_p,$field_val,$field,$polozky)=@_;
   my $dbh=My->dbh;
   my $sth=$dbh->prepare(q{
      select
         Ind_Naradi_norma.ind
      from
         Vyroba_priprava.Ind_Naradi_norma
      where
         Ind_Naradi_norma.ind=?
   });
   $sth->execute($field_val);
   if(!$sth->rows) {
      $field_val=undef;
   }
   $sth->finish;
   return $field_val;
}
#- kontrola inidikace
sub exist_ind_material_norma {
   my ($pkg_p,$field_val,$field,$polozky)=@_;
   my $dbh=My->dbh;
   my $sth=$dbh->prepare(q{
      select
         Ind_Material_norma.ind
      from
         Vyroba_priprava.Ind_Material_norma
      where
         Ind_Material_norma.ind=?
   });
   $sth->execute($field_val);
   if(!$sth->rows) {
      $field_val=undef;
   }
   $sth->finish;
   return $field_val;
}
#- kontrola tarifni tridy
sub exist_tt {
   my ($pkg_p,$field_val,$field,$polozky)=@_;
   my $dbh=My->dbh;
   my $sth=$dbh->prepare(q{
      select
         Sazebnik.tt
      from
         Spolecnost.Sazebnik
      where
         Sazebnik.tt=? and
         Sazebnik.platod<=? and
         Sazebnik.platdo>=?
   });
   $sth->execute($field_val,get_env("datum"),get_env("datum"));
   if(!$sth->rows) {
      $field_val=undef;
   }
   $sth->finish;
   return $field_val;
}
#- kontrola znr (u evidence vyroby)
sub exist_znr {
   my ($pkg_p, $field_val,$field,$polozky)=@_;
   my $dbh=My->dbh;
   my $sth=$dbh->prepare(q{
      select
         Znr.znr
      from
         Vyroba_evidence.Znr
      where
         Znr.znr=?
   });
   $sth->execute($field_val);
   if(!$sth->rows) {
      $field_val=undef;
   }
   # znR 9 je spec. znak uzity jen v ramci zmetkovani pri zapisu imaginarniho prijmu (pri odvadeni nepouzitelny a ja ho zde proste neumoznuji)
   elsif($field_val eq "9") {
      $field_val=undef;
   }
   # znR 6 je mozne vyuzit jen ve fci dilo - tedy mohou uzit jen opticke dilny
   elsif(defined(get_env("vyrtyp")) and get_env("vyrtyp") ne "dilopt" and ($field_val eq "6")) {
      $field_val=undef;
   }
   $sth->finish;
   return $field_val;
}
#- kontrola ucet
sub exist_ucet {
   my ($pkg_p, $field_val)=@_;
   my $dbh=My->dbh;
   my $sth=$dbh->prepare(q{
      select
         UcetOsnova.ucet
      from
         Ucetnictvi.UcetOsnova
      where
         UcetOsnova.ucet=? and
         UcetOsnova.platod<=? and
         UcetOsnova.platdo>=?
   });
   $sth->execute($field_val,get_env("datum"),get_env("datum"));
   if(!$sth->rows) {
      $field_val=undef;
   }
   $sth->finish;
   return $field_val;
}
#- kontrola ucet - jde jen o "ucty", ktere se uzivaji pri odvadeni ve vyrobe, ve skutecnosti nejde nekdy primo o konkretni ucet, ale o skupinu uctu
sub exist_ucet_vyroba {
   my ($pkg_p, $field_val)=@_;
   my $dbh=My->dbh;
   my $sth=$dbh->prepare(q{
      select
         UcetOsnova_vyroba.ucet
      from
         Ucetnictvi.UcetOsnova_vyroba
      where
         UcetOsnova_vyroba.ucet=?
   });
   $sth->execute($field_val);
   if(!$sth->rows) {
      $field_val=undef;
   }
   $sth->finish;
   return $field_val;
}
#- kontrola existence statu
sub exist_stat {
   my ($pkg_p, $field_val)=@_;
   my $ref=Info->stat($field_val);
   if(!$$ref{_exist}) {
      $field_val=undef;
   }
   return $field_val;
}
#- kontrola existence cisla objkednavky
sub exist_cnobj {
   my ($pkg_p, $field_val,$field,$polozky)=@_;
   my $info_objnak=Info->objnak($field_val);
   if(!$$info_objnak{_exist}) {
      $field_val=undef;
   }
   return $field_val;
}
#- kontrola, zda existuje zadany okruh
sub exist_okruh {
   my ($pkg_p, $field_val)=@_;
   my $info_okruh=Info->okruh($field_val);
   if(!$$info_okruh{_exist}) {
      $field_val=undef;
   }
   return $field_val;
}
sub exist_uziv {
   my ($pkg_p, $field_val)=@_;
   my $info_uziv=Info->uziv($field_val);
   if(!$$info_uziv{_exist}) {
      $field_val=undef;
   }
   return $field_val;
}
sub exist_uziv_prava {
   my ($pkg_p, $field_val)=@_;
   if($field_val ne "*") {
      $field_val=$pkg->exist_uziv($field_val);
   }
   return $field_val;
}
#- kontrola, zda jde o cislo
sub check_cislo {
   my ($pkg_p, $field_val,$field,$polozky)=@_;
   if($field_val!~/^[\+\-]{0,1}\d+\.{0,1}\d*$/) {
      $field_val=undef
   }
   return $field_val;
}
#- kontrola, zda jde o nezaporne cislo a zaroven dojde k zaokrouhleni na 0 des mist
sub check_nezaporne0 {
   my ($pkg_p, $field_val,$field,$polozky)=@_;
   $field_val*=1;
   if($field_val<0) {
      $field_val=undef
   }
   else {
      $field_val=sprintf("%.0f",$field_val);
   }
   return $field_val;
}
#- kontrola, zda jde o nezaporne cislo a zaroven dojde k zaokrouhleni na 2 des mista
sub check_nezaporne2 {
   my ($pkg_p, $field_val,$field,$polozky)=@_;
   $field_val*=1;
   if($field_val<0) {
      $field_val=undef
   }
   else {
      $field_val=sprintf("%.2f",$field_val);
   }
   return $field_val;
}
#- kontrola, zda jde o nezaporne cislo a zaroven dojde k zaokrouhleni na 2 des mista
sub check_nezaporne3 {
   my ($pkg_p, $field_val,$field,$polozky)=@_;
   $field_val*=1;
   if($field_val<0) {
      $field_val=undef
   }
   else {
      $field_val=sprintf("%.3f",$field_val);
   }
   return $field_val;
}
#- kontrola, zda jde o nezaporne cislo a zaroven dojde k zaokrouhleni na 4 des mista
sub check_nezaporne4 {
   my ($pkg_p, $field_val,$field,$polozky)=@_;
   $field_val*=1;
   if($field_val<0) {
      $field_val=undef
   }
   else {
      $field_val=sprintf("%.4f",$field_val);
   }
   return $field_val;
}


#======== Funkce kontrolujici zda je vstup ok - jde vsak o oblast zjistovani zda je pravo
#- vraci zda ma surfar pravo na caststr - chce to zrychlit ta metoda je prilis zdlouhava  (prilis sahas do stredisek)
sub checkpravo_strcast {
   my ($pkg_p, $strcast)=@_;
   my $pravo=1;
   my $okruh=My->okruh;
   my $uziv=My->remote_user;
   my $str_h=My->str($okruh,$uziv);
   my $dbh=My->dbh;
   my $sth=$dbh->prepare(q{
      select
         Str.str
      from
         Spolecnost.Str
      where
         Str.str like ? and
         Str.platod<=? and
         Str.platdo>=?
   });
   $sth->execute($strcast."%",get_env("datum"),get_env("datum"));
   while(my $ref=$sth->fetchrow_hashref) {
      if(!$$str_h{$$ref{str}}) {
         $pravo=0;
         last;
      }
   }
   $sth->finish;
   if(!$pravo) {
      $strcast=undef;
   }
   return $strcast;
}

#- vraci zda ma surfar pravo v aktualni okruhu na danne oc
sub checkpravo_oc {
   my ($pkg_p, $oc)=@_;
   # kdyz ma je surfarovo oc totozne se zkoumanym je pravo a tedy jiz neproveruj prava kolem stredisek
   my $dbh=My->dbh;
   my $sth=$dbh->prepare(q{
      select
         Uzivatele.oc
      from
         Zamestnanci.Uzivatele
      where
         Uzivatele.uziv=?
   });
   $sth->execute(My->remote_user);
   my $ref=$sth->fetchrow_hashref;
   $sth->finish;
   if($oc ne $$ref{oc}) {
      # zjisteni z prav stredisek
      ## ZMENA 2003-01-24 - prepinac ucetobd zajisti, ze hledam posledni platny zaznam v ramci ucetniho obdobi danem promenou get_env("datum") (tedy ne zaznam dany datumem)
      my $zamestnanec=Info->oc($oc,{ucetobd=>1});
      my $str_h=My->str;
      if(!$$str_h{$$zamestnanec{str}}) {
         $oc=undef;
      }
   }
   return $oc;
}

#- kontrola, zda je na stredisko pravo a zda jde o stredisko sklhv
sub check_strsklhv_pravo {
   my ($pkg_p, $str)=@_;
   # jde o sklhv?
   my $info_str=Info->str($str);
   if($$info_str{org} ne get_env("org") or $$info_str{vyrtyp} ne "sklhv") {
      $str=undef;
   }
   else {
      # je pravo?
      my $str_pravo=My->str;
      if(!($$str_pravo{$str})) {
         $str=undef;
      }
   }
   return $str;
}

return 1;

